aboutsummaryrefslogtreecommitdiffstats
path: root/java/src/com/android/inputmethod/accessibility/AccessibleKeyboardViewProxy.java
diff options
context:
space:
mode:
Diffstat (limited to 'java/src/com/android/inputmethod/accessibility/AccessibleKeyboardViewProxy.java')
-rw-r--r--java/src/com/android/inputmethod/accessibility/AccessibleKeyboardViewProxy.java10
1 files changed, 5 insertions, 5 deletions
diff --git a/java/src/com/android/inputmethod/accessibility/AccessibleKeyboardViewProxy.java b/java/src/com/android/inputmethod/accessibility/AccessibleKeyboardViewProxy.java
index 77940c086..01220a58a 100644
--- a/java/src/com/android/inputmethod/accessibility/AccessibleKeyboardViewProxy.java
+++ b/java/src/com/android/inputmethod/accessibility/AccessibleKeyboardViewProxy.java
@@ -105,15 +105,15 @@ public class AccessibleKeyboardViewProxy extends AccessibilityDelegateCompat {
}
/**
* Receives motion events when touch exploration is turned on in SDK
* versions ICS and higher.
*
- * @param event The motion event.
+ * @param event The motion event being dispatched.
* @return {@code true} if the event is handled
*/
- public boolean onTouchEvent(MotionEvent event) {
+ public boolean dispatchTouchEvent(MotionEvent event) {
// To avoid accidental key presses during touch exploration, always drop
- // non-hover touch events.
+ // touch events generated by the user.
return false;
}
@@ -105,15 +105,15 @@ public class AccessibleKeyboardViewProxy extends AccessibilityDelegateCompat {
}
/**
- * Receives motion events when touch exploration is turned on in SDK
- * versions ICS and higher.
+ * Intercepts touch events before dispatch when touch exploration is turned
+ * on in ICS and higher.
*